/* GDK - The GIMP Drawing Kit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
 */

#include "config.h"

#include "gdktypes.h"
#include "gdkinternals.h"

#include <stdio.h>

guint               _gdk_debug_flags = 0;
GList              *_gdk_default_filters = NULL;
gchar              *_gdk_display_name = NULL;
gchar              *_gdk_display_arg_name = NULL;
gboolean            _gdk_disable_multidevice = FALSE;
guint               _gdk_gl_flags = 0;
guint               _gdk_vulkan_flags = 0;
GdkRenderingMode    _gdk_rendering_mode = GDK_RENDERING_MODE_SIMILAR;
